@@ -6,7 +6,7 @@ use 5.012;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.1.0.2'; # TRIAL
+our $VERSION = 'v0.1.0.3'; # TRIAL
 
 use File::Basename;
 use File::Spec;
@@ -24,7 +24,7 @@ sub copy_file {
 
     if ( is_windows() ) {
         my $exec = Rex::Interface::Exec->create;
-        $exec->exec("xcopy $original_file $impostor_file");
+        $exec->exec("copy /v /y $original_file $impostor_file");
     }
     else {
         cp $original_file, $impostor_file;
@@ -63,7 +63,7 @@ Rex::Hook::File::Impostor - execute Rex file management commands on a copy of th
 
 =head1 VERSION
 
-version v0.1.0.2
+version v0.1.0.3
 
 =head1 SYNOPSIS
 
